==> bfilter-0.10.1.tar.gz: bfilter-0.10.1/main/ServerConnection.cpp <==
/*
    BFilter - a smart ad-filtering web proxy
    Copyright (C) 2002-2005  Joseph Artsimovich <joseph_a@mail.ru>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "pch.h"

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "ServerConnection.h"

ServerConnection::ServerConnection()
:	m_willPersist(true),
	m_numResponses(0),
	m_minResponseVersion(0, 0),
	m_maxResponseVersion(0, 0)
{
}

ServerConnection::~ServerConnection()
{
}

void
ServerConnection::registerResponse(HttpVersion const& version)
{
	if (m_numResponses++ == 0) {
		m_minResponseVersion = m_maxResponseVersion = version;
	} else {
		if (version > m_maxResponseVersion) {
			m_maxResponseVersion = version;
		}
		if (version < m_minResponseVersion) {
			m_minResponseVersion = version;
		}
	}
}

void
ServerConnection::onNewConnection()
{
	m_willPersist = true;
	m_numResponses = 0;
	m_minResponseVersion = HttpVersion(0, 0);
	m_maxResponseVersion = HttpVersion(0, 0);
}

==> bfilter_1.0.2.orig.tar.gz: bfilter-1.0.2/main/ServerConnection.cpp <==
/*
    BFilter - a smart ad-filtering web proxy
    Copyright (C) 2002-2006  Joseph Artsimovich <joseph_a@mail.ru>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "pch.h"

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "ServerConnection.h"
#include <ace/config-lite.h>
#include <ace/os_include/netinet/os_tcp.h> // FOR TCP_NODELAY

ServerConnection::ServerConnection(
	SymbolicInetAddr const& addr, ACE_SOCK_Stream const& peer)
:	m_symbolicAddr(addr),
	m_peer(peer),
	m_willPersist(true),
	m_numResponses(0),
	m_minResponseVersion(0, 0),
	m_maxResponseVersion(0, 0)
{
}

ServerConnection::~ServerConnection()
{
	m_peer.close();
}

void
ServerConnection::registerResponse(HttpVersion const& version)
{
	if (m_numResponses++ == 0) {
		m_minResponseVersion = m_maxResponseVersion = version;
	} else {
		if (version > m_maxResponseVersion) {
			m_maxResponseVersion = version;
		}
		if (version < m_minResponseVersion) {
			m_minResponseVersion = version;
		}
	}
}

void
ServerConnection::setTcpNoDelay(bool value)
{
#if !defined(ACE_LACKS_TCPNODELAY)
	int val = (value ? 1 : 0);
	m_peer.set_option(ACE_IPPROTO_TCP, TCP_NODELAY, &val, sizeof(val));
#endif
}
